aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/Makefile.global.in16
-rw-r--r--src/backend/access/transam/Makefile15
-rw-r--r--src/backend/catalog/Makefile12
-rw-r--r--src/backend/catalog/genbki.sh14
-rw-r--r--src/backend/libpq/pqsignal.c4
-rw-r--r--src/backend/port/gethostname.c6
-rw-r--r--src/backend/port/inet_aton.c6
-rw-r--r--src/backend/port/isinf.c6
-rw-r--r--src/backend/port/qnx4/isnan.c4
-rw-r--r--src/backend/port/qnx4/rint.c4
-rw-r--r--src/backend/port/qnx4/sem.c5
-rw-r--r--src/backend/port/qnx4/shm.c4
-rw-r--r--src/backend/port/qnx4/tstrint.c5
-rw-r--r--src/backend/port/qnx4/tstsem.c4
-rw-r--r--src/backend/port/qnx4/tstshm.c4
-rw-r--r--src/backend/port/random.c6
-rw-r--r--src/backend/port/srandom.c6
-rw-r--r--src/backend/storage/smgr/md.c4
-rw-r--r--src/backend/utils/adt/int8.c4
-rw-r--r--src/include/Makefile6
-rw-r--r--src/include/c.h12
-rw-r--r--src/include/pg_config.h.in (renamed from src/include/config.h.in)20
-rw-r--r--src/include/pg_config.h.win32 (renamed from src/include/config.h.win32)6
-rw-r--r--src/interfaces/ecpg/lib/connect.c4
-rw-r--r--src/interfaces/ecpg/lib/data.c4
-rw-r--r--src/interfaces/ecpg/lib/descriptor.c4
-rw-r--r--src/interfaces/ecpg/lib/error.c4
-rw-r--r--src/interfaces/ecpg/lib/execute.c7
-rw-r--r--src/interfaces/ecpg/lib/memory.c4
-rw-r--r--src/interfaces/ecpg/lib/misc.c4
-rw-r--r--src/interfaces/ecpg/lib/prepare.c4
-rw-r--r--src/interfaces/ecpg/lib/typename.c4
-rw-r--r--src/interfaces/libpq++/pgconnection.h6
-rw-r--r--src/interfaces/odbc/bind.c5
-rw-r--r--src/interfaces/odbc/columninfo.c1
-rw-r--r--src/interfaces/odbc/connection.c5
-rw-r--r--src/interfaces/odbc/connection.h8
-rw-r--r--src/interfaces/odbc/convert.c7
-rw-r--r--src/interfaces/odbc/convert.h2
-rw-r--r--src/interfaces/odbc/dlg_specific.c4
-rw-r--r--src/interfaces/odbc/dlg_specific.h4
-rw-r--r--src/interfaces/odbc/drvconn.c5
-rw-r--r--src/interfaces/odbc/environ.c1
-rw-r--r--src/interfaces/odbc/environ.h4
-rw-r--r--src/interfaces/odbc/execute.c4
-rw-r--r--src/interfaces/odbc/gpps.c11
-rw-r--r--src/interfaces/odbc/gpps.h4
-rw-r--r--src/interfaces/odbc/info.c5
-rw-r--r--src/interfaces/odbc/misc.c8
-rw-r--r--src/interfaces/odbc/misc.h4
-rw-r--r--src/interfaces/odbc/multibyte.c2
-rw-r--r--src/interfaces/odbc/multibyte.h1
-rw-r--r--src/interfaces/odbc/odbcapi.c4
-rw-r--r--src/interfaces/odbc/odbcapi30.c4
-rw-r--r--src/interfaces/odbc/options.c4
-rw-r--r--src/interfaces/odbc/parse.c4
-rw-r--r--src/interfaces/odbc/pgapifunc.h3
-rw-r--r--src/interfaces/odbc/pgtypes.c6
-rw-r--r--src/interfaces/odbc/psqlodbc.c4
-rw-r--r--src/interfaces/odbc/psqlodbc.h4
-rw-r--r--src/interfaces/odbc/qresult.h3
-rw-r--r--src/interfaces/odbc/results.c5
-rw-r--r--src/interfaces/odbc/socket.c4
-rw-r--r--src/interfaces/odbc/socket.h4
-rw-r--r--src/interfaces/odbc/statement.c4
-rw-r--r--src/interfaces/odbc/statement.h4
-rw-r--r--src/interfaces/odbc/tuplelist.c2
-rw-r--r--src/interfaces/python/GNUmakefile3
-rwxr-xr-xsrc/tools/pginclude/pgrminclude2
69 files changed, 150 insertions, 217 deletions
diff --git a/src/Makefile.global.in b/src/Makefile.global.in
index a447d4e87c3..1b1abc8f207 100644
--- a/src/Makefile.global.in
+++ b/src/Makefile.global.in
@@ -1,5 +1,5 @@
# -*-makefile-*-
-# $Header: /cvsroot/pgsql/src/Makefile.global.in,v 1.131 2001/07/15 11:20:01 petere Exp $
+# $Header: /cvsroot/pgsql/src/Makefile.global.in,v 1.132 2001/08/24 14:07:48 petere Exp $
#------------------------------------------------------------------------------
# All PostgreSQL makefiles include this file and use the variables it sets,
@@ -321,20 +321,20 @@ STRTOUL = @STRTOUL@
$(top_builddir)/src/Makefile.global: $(top_srcdir)/src/Makefile.global.in $(top_builddir)/config.status
cd $(top_builddir) && CONFIG_FILES=src/Makefile.global CONFIG_HEADERS= ./config.status
-# Remake config.h from config.h.in if the latter changed.
-# config.status will not change the timestamp on config.h if it
+# Remake pg_config.h from pg_config.h.in if the latter changed.
+# config.status will not change the timestamp on pg_config.h if it
# doesn't change, so as to avoid recompiling the entire tree
# unnecessarily. Therefore we make config.status update a timestamp file
# stamp-h everytime it runs, so that we don't trigger this rule everytime.
-# (We do trigger the null rule for stamp-h to config.h everytime; so it's
+# (We do trigger the null rule for stamp-h to pg_config.h everytime; so it's
# important for that rule to be null!)
#
# Of course you need to turn on dependency tracking to get any
-# dependencies on config.h.
-$(top_builddir)/src/include/config.h: $(top_builddir)/src/include/stamp-h
+# dependencies on pg_config.h.
+$(top_builddir)/src/include/pg_config.h: $(top_builddir)/src/include/stamp-h
-$(top_builddir)/src/include/stamp-h: $(top_srcdir)/src/include/config.h.in $(top_builddir)/config.status
- cd $(top_builddir) && CONFIG_FILES= CONFIG_HEADERS=src/include/config.h ./config.status
+$(top_builddir)/src/include/stamp-h: $(top_srcdir)/src/include/pg_config.h.in $(top_builddir)/config.status
+ cd $(top_builddir) && CONFIG_FILES= CONFIG_HEADERS=src/include/pg_config.h ./config.status
# When configure changes, rerun configure with the same options as
# last time. To change configure, you need to run autoconf manually.
diff --git a/src/backend/access/transam/Makefile b/src/backend/access/transam/Makefile
index 272a883c521..c4adcc5bffa 100644
--- a/src/backend/access/transam/Makefile
+++ b/src/backend/access/transam/Makefile
@@ -4,7 +4,7 @@
# Makefile for access/transam
#
# IDENTIFICATION
-# $Header: /cvsroot/pgsql/src/backend/access/transam/Makefile,v 1.13 2000/10/13 12:05:21 vadim Exp $
+# $Header: /cvsroot/pgsql/src/backend/access/transam/Makefile,v 1.14 2001/08/24 14:07:48 petere Exp $
#
#-------------------------------------------------------------------------
@@ -19,17 +19,8 @@ all: SUBSYS.o
SUBSYS.o: $(OBJS)
$(LD) $(LDREL) $(LDOUT) SUBSYS.o $(OBJS)
-depend dep:
- $(CC) -MM $(CFLAGS) *.c >depend
-
clean:
rm -f SUBSYS.o $(OBJS)
-# ensure that version checks in xlog.c get recompiled when config.h or
-# catversion.h changes, even if "make depend" hasn't been done.
-xlog.o: xlog.c $(top_builddir)/src/include/config.h $(top_srcdir)/src/include/catalog/catversion.h
-
-ifeq (depend,$(wildcard depend))
-include depend
-endif
-
+# ensure that version checks in xlog.c get recompiled when catversion.h changes
+xlog.o: xlog.c $(top_srcdir)/src/include/catalog/catversion.h
diff --git a/src/backend/catalog/Makefile b/src/backend/catalog/Makefile
index 07801c9a14e..999897d9fee 100644
--- a/src/backend/catalog/Makefile
+++ b/src/backend/catalog/Makefile
@@ -2,7 +2,7 @@
#
# Makefile for catalog
#
-# $Header: /cvsroot/pgsql/src/backend/catalog/Makefile,v 1.35 2001/06/12 05:55:49 tgl Exp $
+# $Header: /cvsroot/pgsql/src/backend/catalog/Makefile,v 1.36 2001/08/24 14:07:48 petere Exp $
#
#-------------------------------------------------------------------------
@@ -37,7 +37,7 @@ POSTGRES_BKI_SRCS := $(addprefix $(top_srcdir)/src/include/catalog/,\
pg_includes := $(sort -I$(top_srcdir)/src/include -I$(top_builddir)/src/include)
postgres.bki postgres.description: genbki.sh $(POSTGRES_BKI_SRCS) \
- $(top_srcdir)/src/include/postgres_ext.h $(top_builddir)/src/include/config.h
+ $(top_srcdir)/src/include/postgres_ext.h $(top_builddir)/src/include/pg_config.h
CPP='$(CPP)' AWK='$(AWK)' $(SHELL) $< $(BKIOPTS) -o postgres $(pg_includes) $(POSTGRES_BKI_SRCS) --set-version=$(VERSION)
.PHONY: install-bki
@@ -55,11 +55,3 @@ uninstall-bki:
clean:
rm -f SUBSYS.o $(OBJS) $(BKIFILES)
-
-
-depend dep:
- $(CC) -MM $(CFLAGS) *.c >depend
-
-ifeq (depend,$(wildcard depend))
-include depend
-endif
diff --git a/src/backend/libpq/pqsignal.c b/src/backend/libpq/pqsignal.c
index 8cc8f140ace..9bdcd27b703 100644
--- a/src/backend/libpq/pqsignal.c
+++ b/src/backend/libpq/pqsignal.c
@@ -9,7 +9,7 @@
*
*
* IDENTIFICATION
- * $Header: /cvsroot/pgsql/src/backend/libpq/pqsignal.c,v 1.20 2001/03/22 03:59:30 momjian Exp $
+ * $Header: /cvsroot/pgsql/src/backend/libpq/pqsignal.c,v 1.21 2001/08/24 14:07:49 petere Exp $
*
* NOTES
* This shouldn't be in libpq, but the monitor and some other
@@ -17,7 +17,7 @@
*
* A NOTE ABOUT SIGNAL HANDLING ACROSS THE VARIOUS PLATFORMS.
*
- * config.h defines the macro HAVE_POSIX_SIGNALS for some platforms and
+ * pg_config.h defines the macro HAVE_POSIX_SIGNALS for some platforms and
* not for others. This file and pqsignal.h use that macro to decide
* how to handle signalling.
*
diff --git a/src/backend/port/gethostname.c b/src/backend/port/gethostname.c
index be7046e7c0e..568a2221a9d 100644
--- a/src/backend/port/gethostname.c
+++ b/src/backend/port/gethostname.c
@@ -1,12 +1,12 @@
-/* $Id: gethostname.c,v 1.4 1998/09/01 03:24:25 momjian Exp $ */
+/* $Id: gethostname.c,v 1.5 2001/08/24 14:07:49 petere Exp $ */
+
+#include "c.h"
#include <sys/types.h>
#include <string.h>
#include <sys/utsname.h>
-#include "config.h"
-
int
gethostname(char *name, int namelen)
{
diff --git a/src/backend/port/inet_aton.c b/src/backend/port/inet_aton.c
index b6cd4974393..81f20da9672 100644
--- a/src/backend/port/inet_aton.c
+++ b/src/backend/port/inet_aton.c
@@ -1,4 +1,4 @@
-/* $Id: inet_aton.c,v 1.18 2000/12/03 20:45:34 tgl Exp $
+/* $Id: inet_aton.c,v 1.19 2001/08/24 14:07:49 petere Exp $
*
* This inet_aton() function was taken from the GNU C library and
* incorporated into Postgres for those systems which do not have this
@@ -42,12 +42,12 @@
* OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGE. */
+#include "c.h"
+
#include <sys/types.h>
#include <netinet/in.h>
#include <ctype.h>
-#include "config.h"
-
/*
* Check whether "cp" is a valid ascii representation
* of an Internet address and convert to a binary address.
diff --git a/src/backend/port/isinf.c b/src/backend/port/isinf.c
index 208cef53494..f589f47816e 100644
--- a/src/backend/port/isinf.c
+++ b/src/backend/port/isinf.c
@@ -1,8 +1,8 @@
-/* $Id: isinf.c,v 1.15 2000/04/12 17:15:28 momjian Exp $ */
+/* $Id: isinf.c,v 1.16 2001/08/24 14:07:49 petere Exp $ */
-#include <math.h>
+#include "c.h"
-#include "config.h"
+#include <math.h>
#if HAVE_FPCLASS /* this is _not_ HAVE_FP_CLASS, and not
* typo */
diff --git a/src/backend/port/qnx4/isnan.c b/src/backend/port/qnx4/isnan.c
index a0afb3d1849..725b26c2eea 100644
--- a/src/backend/port/qnx4/isnan.c
+++ b/src/backend/port/qnx4/isnan.c
@@ -7,12 +7,12 @@
*
*
* IDENTIFICATION
- * $Header: /cvsroot/pgsql/src/backend/port/qnx4/Attic/isnan.c,v 1.2 2000/04/12 17:15:30 momjian Exp $
+ * $Header: /cvsroot/pgsql/src/backend/port/qnx4/Attic/isnan.c,v 1.3 2001/08/24 14:07:49 petere Exp $
*
*-------------------------------------------------------------------------
*/
-#include "os.h"
+#include "c.h"
unsigned char __nan[8] = __nan_bytes;
diff --git a/src/backend/port/qnx4/rint.c b/src/backend/port/qnx4/rint.c
index 4450d8c0567..972c51e74bf 100644
--- a/src/backend/port/qnx4/rint.c
+++ b/src/backend/port/qnx4/rint.c
@@ -7,13 +7,13 @@
*
*
* IDENTIFICATION
- * $Header: /cvsroot/pgsql/src/backend/port/qnx4/Attic/rint.c,v 1.2 2000/04/12 17:15:30 momjian Exp $
+ * $Header: /cvsroot/pgsql/src/backend/port/qnx4/Attic/rint.c,v 1.3 2001/08/24 14:07:49 petere Exp $
*
*-------------------------------------------------------------------------
*/
+#include "c.h"
#include <math.h>
-#include "os.h"
double
rint(double x)
diff --git a/src/backend/port/qnx4/sem.c b/src/backend/port/qnx4/sem.c
index 188a5f0616f..98fcc28993d 100644
--- a/src/backend/port/qnx4/sem.c
+++ b/src/backend/port/qnx4/sem.c
@@ -7,11 +7,13 @@
*
*
* IDENTIFICATION
- * $Header: /cvsroot/pgsql/src/backend/port/qnx4/Attic/sem.c,v 1.5 2001/05/24 15:53:33 momjian Exp $
+ * $Header: /cvsroot/pgsql/src/backend/port/qnx4/Attic/sem.c,v 1.6 2001/08/24 14:07:49 petere Exp $
*
*-------------------------------------------------------------------------
*/
+#include "postgres.h"
+
#include <errno.h>
#include <semaphore.h>
#include <string.h>
@@ -19,7 +21,6 @@
#include <unistd.h>
#include <fcntl.h>
#include <sys/mman.h>
-#include "postgres.h"
#include "storage/ipc.h"
#include "storage/proc.h"
#include <sys/sem.h>
diff --git a/src/backend/port/qnx4/shm.c b/src/backend/port/qnx4/shm.c
index b96203f1c2d..466c4b4b402 100644
--- a/src/backend/port/qnx4/shm.c
+++ b/src/backend/port/qnx4/shm.c
@@ -7,11 +7,13 @@
*
*
* IDENTIFICATION
- * $Header: /cvsroot/pgsql/src/backend/port/qnx4/Attic/shm.c,v 1.5 2001/05/24 15:53:33 momjian Exp $
+ * $Header: /cvsroot/pgsql/src/backend/port/qnx4/Attic/shm.c,v 1.6 2001/08/24 14:07:49 petere Exp $
*
*-------------------------------------------------------------------------
*/
+#include "postgres.h"
+
#include <errno.h>
#include <fcntl.h>
#include <stdlib.h>
diff --git a/src/backend/port/qnx4/tstrint.c b/src/backend/port/qnx4/tstrint.c
index 222051692a8..5586edb6787 100644
--- a/src/backend/port/qnx4/tstrint.c
+++ b/src/backend/port/qnx4/tstrint.c
@@ -7,15 +7,16 @@
*
*
* IDENTIFICATION
- * $Header: /cvsroot/pgsql/src/backend/port/qnx4/Attic/tstrint.c,v 1.2 2000/04/12 17:15:30 momjian Exp $
+ * $Header: /cvsroot/pgsql/src/backend/port/qnx4/Attic/tstrint.c,v 1.3 2001/08/24 14:07:49 petere Exp $
*
*-------------------------------------------------------------------------
*/
+#include "c.h"
+
#include <errno.h>
#include <stdio.h>
#include <stdlib.h>
-#include "os.h"
int
diff --git a/src/backend/port/qnx4/tstsem.c b/src/backend/port/qnx4/tstsem.c
index c58a724f9d0..571a6def252 100644
--- a/src/backend/port/qnx4/tstsem.c
+++ b/src/backend/port/qnx4/tstsem.c
@@ -7,17 +7,17 @@
*
*
* IDENTIFICATION
- * $Header: /cvsroot/pgsql/src/backend/port/qnx4/Attic/tstsem.c,v 1.4 2001/05/24 15:53:33 momjian Exp $
+ * $Header: /cvsroot/pgsql/src/backend/port/qnx4/Attic/tstsem.c,v 1.5 2001/08/24 14:07:49 petere Exp $
*
*-------------------------------------------------------------------------
*/
+#include "postgres.h"
#include <signal.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
-#include "postgres.h"
#include "storage/ipc.h"
#include <sys/mman.h>
#include <sys/sem.h>
diff --git a/src/backend/port/qnx4/tstshm.c b/src/backend/port/qnx4/tstshm.c
index d6e577f2924..0fd8226faad 100644
--- a/src/backend/port/qnx4/tstshm.c
+++ b/src/backend/port/qnx4/tstshm.c
@@ -7,11 +7,13 @@
*
*
* IDENTIFICATION
- * $Header: /cvsroot/pgsql/src/backend/port/qnx4/Attic/tstshm.c,v 1.2 2000/04/12 17:15:30 momjian Exp $
+ * $Header: /cvsroot/pgsql/src/backend/port/qnx4/Attic/tstshm.c,v 1.3 2001/08/24 14:07:49 petere Exp $
*
*-------------------------------------------------------------------------
*/
+#include "postgres.h"
+
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
diff --git a/src/backend/port/random.c b/src/backend/port/random.c
index 950b9106eca..882a3fbf529 100644
--- a/src/backend/port/random.c
+++ b/src/backend/port/random.c
@@ -1,11 +1,11 @@
-/* $Id: random.c,v 1.9 1999/07/16 23:09:45 tgl Exp $ */
+/* $Id: random.c,v 1.10 2001/08/24 14:07:49 petere Exp $ */
+
+#include "c.h"
#include <stdlib.h>
#include <math.h>
#include <errno.h>
-#include "config.h"
-
long
random()
{
diff --git a/src/backend/port/srandom.c b/src/backend/port/srandom.c
index eb16736d4ce..5f61088be69 100644
--- a/src/backend/port/srandom.c
+++ b/src/backend/port/srandom.c
@@ -1,11 +1,11 @@
-/* $Id: srandom.c,v 1.9 1999/07/16 23:09:45 tgl Exp $ */
+/* $Id: srandom.c,v 1.10 2001/08/24 14:07:49 petere Exp $ */
+
+#include "c.h"
#include <stdlib.h>
#include <math.h>
#include <errno.h>
-#include "config.h"
-
void
srandom(unsigned int seed)
{
diff --git a/src/backend/storage/smgr/md.c b/src/backend/storage/smgr/md.c
index 54054ee137e..424b667c630 100644
--- a/src/backend/storage/smgr/md.c
+++ b/src/backend/storage/smgr/md.c
@@ -8,7 +8,7 @@
*
*
* IDENTIFICATION
- * $Header: /cvsroot/pgsql/src/backend/storage/smgr/md.c,v 1.86 2001/06/27 23:31:39 tgl Exp $
+ * $Header: /cvsroot/pgsql/src/backend/storage/smgr/md.c,v 1.87 2001/08/24 14:07:49 petere Exp $
*
*-------------------------------------------------------------------------
*/
@@ -36,7 +36,7 @@
* to support relations larger than the OS' file size limit (often 2GBytes).
* In order to do that, we break relations up into chunks of < 2GBytes
* and store one chunk in each of several files that represent the relation.
- * See the BLCKSZ and RELSEG_SIZE configuration constants in include/config.h.
+ * See the BLCKSZ and RELSEG_SIZE configuration constants in include/pg_config.h.
*
* The file descriptor stored in the relation cache (see RelationGetFile())
* is actually an index into the Md_fdvec array. -1 indicates not open.
diff --git a/src/backend/utils/adt/int8.c b/src/backend/utils/adt/int8.c
index 711c17ad8ad..7a93d219d70 100644
--- a/src/backend/utils/adt/int8.c
+++ b/src/backend/utils/adt/int8.c
@@ -7,7 +7,7 @@
* Portions Copyright (c) 1994, Regents of the University of California
*
* IDENTIFICATION
- * $Header: /cvsroot/pgsql/src/backend/utils/adt/int8.c,v 1.31 2001/08/14 22:21:58 tgl Exp $
+ * $Header: /cvsroot/pgsql/src/backend/utils/adt/int8.c,v 1.32 2001/08/24 14:07:49 petere Exp $
*
*-------------------------------------------------------------------------
*/
@@ -21,7 +21,7 @@
#include "utils/int8.h"
-/* this should be set in config.h, but just in case it wasn't: */
+/* this should be set in pg_config.h, but just in case it wasn't: */
#ifndef INT64_FORMAT
#define INT64_FORMAT "%ld"
#endif
diff --git a/src/include/Makefile b/src/include/Makefile
index 7d8a3e5b7f5..a8aed3fdd70 100644
--- a/src/include/Makefile
+++ b/src/include/Makefile
@@ -6,7 +6,7 @@
# programming. 'make install-all-headers' installs the whole contents
# of src/include.
#
-# $Header: /cvsroot/pgsql/src/include/Makefile,v 1.8 2001/03/01 16:17:53 petere Exp $
+# $Header: /cvsroot/pgsql/src/include/Makefile,v 1.9 2001/08/24 14:07:49 petere Exp $
#
#-------------------------------------------------------------------------
@@ -18,7 +18,7 @@ include $(top_builddir)/src/Makefile.global
srcdir_headers := c.h postgres_ext.h postgres_fe.h \
libpq/pqcomm.h libpq/libpq-fs.h lib/dllist.h
-builddir_headers := os.h config.h
+builddir_headers := pg_config_os.h pg_config.h
HEADERS = $(srcdir_headers) $(builddir_headers)
@@ -91,4 +91,4 @@ clean:
rm -f utils/fmgroids.h parser/parse.h
distclean maintainer-clean: clean
- rm -f config.h dynloader.h os.h stamp-h
+ rm -f pg_config.h dynloader.h pg_config_os.h stamp-h
diff --git a/src/include/c.h b/src/include/c.h
index d67dee12ac6..fc95d381d39 100644
--- a/src/include/c.h
+++ b/src/include/c.h
@@ -12,7 +12,7 @@
* Portions Copyright (c) 1996-2001, PostgreSQL Global Development Group
* Portions Copyright (c) 1994, Regents of the University of California
*
- * $Id: c.h,v 1.98 2001/08/23 23:06:38 tgl Exp $
+ * $Id: c.h,v 1.99 2001/08/24 14:07:49 petere Exp $
*
*-------------------------------------------------------------------------
*/
@@ -25,7 +25,7 @@
*
* section description
* ------- ------------------------------------------------
- * 0) config.h and standard system headers
+ * 0) pg_config.h and standard system headers
* 1) hacks to cope with non-ANSI C compilers
* 2) bool, true, false, TRUE, FALSE, NULL
* 3) standard system types
@@ -49,7 +49,7 @@
have its own. The same goes for stddef and stdarg if present.
*/
-#include "config.h"
+#include "pg_config.h"
#include <stdio.h>
#include <stdlib.h>
@@ -79,7 +79,7 @@
/* ----------------------------------------------------------------
* Section 1: hacks to cope with non-ANSI C compilers
*
- * type prefixes (const, signed, volatile, inline) are now handled in config.h.
+ * type prefixes (const, signed, volatile, inline) are handled in pg_config.h.
* ----------------------------------------------------------------
*/
@@ -624,8 +624,8 @@ typedef NameData *Name;
#endif
/* Provide prototypes for routines not present in a particular machine's
- * standard C library. It'd be better to put these in config.h, but
- * in config.h we haven't yet included anything that defines size_t...
+ * standard C library. It'd be better to put these in pg_config.h, but
+ * in pg_config.h we haven't yet included anything that defines size_t...
*/
#ifndef HAVE_SNPRINTF_DECL
diff --git a/src/include/config.h.in b/src/include/pg_config.h.in
index c0559089eb6..c0984313e1e 100644
--- a/src/include/config.h.in
+++ b/src/include/pg_config.h.in
@@ -1,18 +1,18 @@
/*
* PostgreSQL configuration-settings file.
*
- * config.h.in is processed by configure to produce config.h.
+ * pg_config.h.in is processed by configure to produce pg_config.h.
*
* If you want to modify any of the tweakable settings in Part 2
- * of this file, you can do it in config.h.in before running configure,
- * or in config.h afterwards. Of course, if you edit config.h, then your
+ * of this file, you can do it in pg_config.h.in before running configure,
+ * or in pg_config.h afterwards. Of course, if you edit pg_config.h, then your
* changes will be overwritten the next time you run configure.
*
- * $Id: config.h.in,v 1.170 2001/08/01 23:52:50 tgl Exp $
+ * $Id: pg_config.h.in,v 1.1 2001/08/24 14:07:49 petere Exp $
*/
-#ifndef CONFIG_H
-#define CONFIG_H
+#ifndef PG_CONFIG_H
+#define PG_CONFIG_H
/*
@@ -690,7 +690,7 @@ extern int fdatasync(int fildes);
* Part 4: pull in system-specific declarations.
*
* This is still configure's responsibility, because it picks where
- * the "os.h" symlink points...
+ * the "pg_config_os.h" symlink points...
*------------------------------------------------------------------------
*/
@@ -698,12 +698,12 @@ extern int fdatasync(int fildes);
* Pull in OS-specific declarations (using link created by configure)
*/
-#include "os.h"
+#include "pg_config_os.h"
/*
* The following is used as the arg list for signal handlers. Any ports
* that take something other than an int argument should override this in
- * the port-specific os.h file. Note that variable names are required
+ * the port-specific pg_config_os.h file. Note that variable names are required
* because it is used in both the prototypes as well as the definitions.
* Note also the long name. We expect that this won't collide with
* other names causing compiler warnings.
@@ -714,4 +714,4 @@ extern int fdatasync(int fildes);
#endif
-#endif /* CONFIG_H */
+#endif /* PG_CONFIG_H */
diff --git a/src/include/config.h.win32 b/src/include/pg_config.h.win32
index e8323b77364..b3977e90c24 100644
--- a/src/include/config.h.win32
+++ b/src/include/pg_config.h.win32
@@ -1,8 +1,8 @@
/*
- * Parts of config.h that you get with autoconf on other systems
+ * Parts of pg_config.h that you get with autoconf on other systems
*/
-#define PG_VERSION "7.2.0"
-#define PG_VERSION_STR "7.2.0 (win32)"
+#define PG_VERSION "7.2"
+#define PG_VERSION_STR "7.2 (win32)"
#define SYSCONFDIR ""
diff --git a/src/interfaces/ecpg/lib/connect.c b/src/interfaces/ecpg/lib/connect.c
index 2618cc37ed8..e70299dc5f4 100644
--- a/src/interfaces/ecpg/lib/connect.c
+++ b/src/interfaces/ecpg/lib/connect.c
@@ -1,3 +1,7 @@
+/* $Header: /cvsroot/pgsql/src/interfaces/ecpg/lib/Attic/connect.c,v 1.11 2001/08/24 14:07:49 petere Exp $ */
+
+#include "postgres_fe.h"
+
#include "ecpgtype.h"
#include "ecpglib.h"
#include "ecpgerrno.h"
diff --git a/src/interfaces/ecpg/lib/data.c b/src/interfaces/ecpg/lib/data.c
index 50640ba1a46..1f6a86f16c9 100644
--- a/src/interfaces/ecpg/lib/data.c
+++ b/src/interfaces/ecpg/lib/data.c
@@ -1,4 +1,6 @@
-#include "config.h"
+/* $Header: /cvsroot/pgsql/src/interfaces/ecpg/lib/Attic/data.c,v 1.14 2001/08/24 14:07:49 petere Exp $ */
+
+#include "postgres_fe.h"
#include <stdlib.h>
#include <string.h>
diff --git a/src/interfaces/ecpg/lib/descriptor.c b/src/interfaces/ecpg/lib/descriptor.c
index 07f12c5f2e2..1312b22e474 100644
--- a/src/interfaces/ecpg/lib/descriptor.c
+++ b/src/interfaces/ecpg/lib/descriptor.c
@@ -1,4 +1,6 @@
-#include "config.h"
+/* $Header: /cvsroot/pgsql/src/interfaces/ecpg/lib/Attic/descriptor.c,v 1.15 2001/08/24 14:07:49 petere Exp $ */
+
+#include "postgres_fe.h"
#include "ecpgtype.h"
#include "ecpglib.h"
diff --git a/src/interfaces/ecpg/lib/error.c b/src/interfaces/ecpg/lib/error.c
index 72b005bb9ac..c16fb8395a0 100644
--- a/src/interfaces/ecpg/lib/error.c
+++ b/src/interfaces/ecpg/lib/error.c
@@ -1,3 +1,7 @@
+/* $Header: /cvsroot/pgsql/src/interfaces/ecpg/lib/Attic/error.c,v 1.9 2001/08/24 14:07:49 petere Exp $ */
+
+#include "postgres_fe.h"
+
#include <stdio.h>
#include "ecpgerrno.h"
diff --git a/src/interfaces/ecpg/lib/execute.c b/src/interfaces/ecpg/lib/execute.c
index c9b66bb36f0..3238fd59bb9 100644
--- a/src/interfaces/ecpg/lib/execute.c
+++ b/src/interfaces/ecpg/lib/execute.c
@@ -1,4 +1,5 @@
-/* Copyright comment */
+/* $Header: /cvsroot/pgsql/src/interfaces/ecpg/lib/Attic/execute.c,v 1.22 2001/08/24 14:07:49 petere Exp $ */
+
/*
* The aim is to get a simpler inteface to the database routines.
* All the tidieous messing around with tuples is supposed to be hidden
@@ -12,7 +13,7 @@
/* Taken over as part of PostgreSQL by Michael Meskes <meskes@postgresql.org>
on Feb. 5th, 1998 */
-#include "config.h"
+#include "postgres_fe.h"
#include <stdio.h>
#include <locale.h>
@@ -1035,7 +1036,7 @@ ECPGdo(int lineno, const char *connection_name, char *query,...)
*
* Copyright (c) 2000, Christof Petig <christof.petig@wtal.de>
*
- * $Header: /cvsroot/pgsql/src/interfaces/ecpg/lib/Attic/execute.c,v 1.21 2001/08/19 09:21:44 meskes Exp $
+ * $Header: /cvsroot/pgsql/src/interfaces/ecpg/lib/Attic/execute.c,v 1.22 2001/08/24 14:07:49 petere Exp $
*/
PGconn *ECPG_internal_get_connection(char *name);
diff --git a/src/interfaces/ecpg/lib/memory.c b/src/interfaces/ecpg/lib/memory.c
index e6ef531128d..d7ff8799635 100644
--- a/src/interfaces/ecpg/lib/memory.c
+++ b/src/interfaces/ecpg/lib/memory.c
@@ -1,3 +1,7 @@
+/* $Header: /cvsroot/pgsql/src/interfaces/ecpg/lib/Attic/memory.c,v 1.4 2001/08/24 14:07:49 petere Exp $ */
+
+#include "postgres_fe.h"
+
#include "ecpgtype.h"
#include "ecpglib.h"
#include "ecpgerrno.h"
diff --git a/src/interfaces/ecpg/lib/misc.c b/src/interfaces/ecpg/lib/misc.c
index c0b585cf1db..4a93be4b905 100644
--- a/src/interfaces/ecpg/lib/misc.c
+++ b/src/interfaces/ecpg/lib/misc.c
@@ -1,3 +1,7 @@
+/* $Header: /cvsroot/pgsql/src/interfaces/ecpg/lib/Attic/misc.c,v 1.4 2001/08/24 14:07:49 petere Exp $ */
+
+#include "postgres_fe.h"
+
#include <unistd.h>
#include "ecpgtype.h"
#include "ecpglib.h"
diff --git a/src/interfaces/ecpg/lib/prepare.c b/src/interfaces/ecpg/lib/prepare.c
index 50900048752..f1c164c7f45 100644
--- a/src/interfaces/ecpg/lib/prepare.c
+++ b/src/interfaces/ecpg/lib/prepare.c
@@ -1,3 +1,7 @@
+/* $Header: /cvsroot/pgsql/src/interfaces/ecpg/lib/Attic/prepare.c,v 1.6 2001/08/24 14:07:49 petere Exp $ */
+
+#include "postgres_fe.h"
+
#include <ctype.h>
#include "ecpgtype.h"
diff --git a/src/interfaces/ecpg/lib/typename.c b/src/interfaces/ecpg/lib/typename.c
index a27aea47438..d41ca583909 100644
--- a/src/interfaces/ecpg/lib/typename.c
+++ b/src/interfaces/ecpg/lib/typename.c
@@ -1,4 +1,6 @@
-#include "config.h"
+/* $Header: /cvsroot/pgsql/src/interfaces/ecpg/lib/Attic/typename.c,v 1.18 2001/08/24 14:07:49 petere Exp $ */
+
+#include "postgres_fe.h"
#include <stdlib.h>
#include "ecpgtype.h"
diff --git a/src/interfaces/libpq++/pgconnection.h b/src/interfaces/libpq++/pgconnection.h
index 379f8d023e7..7d8ca2c52bf 100644
--- a/src/interfaces/libpq++/pgconnection.h
+++ b/src/interfaces/libpq++/pgconnection.h
@@ -13,7 +13,7 @@
* Portions Copyright (c) 1996-2001, PostgreSQL Global Development Group
* Portions Copyright (c) 1994, Regents of the University of California
*
- * $Id: pgconnection.h,v 1.12 2001/07/11 22:12:43 momjian Exp $
+ * $Id: pgconnection.h,v 1.13 2001/08/24 14:07:49 petere Exp $
*
*-------------------------------------------------------------------------
*/
@@ -22,11 +22,11 @@
#define PGCONNECTION_H
extern "C" {
-#include "config.h"
+#include "pg_config.h"
}
/* We assume that the C++ compiler will have these keywords, even though
- * config.h may have #define'd them to empty because C compiler doesn't.
+ * pg_config.h may have #define'd them to empty because C compiler doesn't.
*/
#undef const
#undef inline
diff --git a/src/interfaces/odbc/bind.c b/src/interfaces/odbc/bind.c
index 469edb6c2ce..2fc340907a3 100644
--- a/src/interfaces/odbc/bind.c
+++ b/src/interfaces/odbc/bind.c
@@ -13,11 +13,8 @@
*-------
*/
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
#include "bind.h"
+
#include "environ.h"
#include "statement.h"
#include "qresult.h"
diff --git a/src/interfaces/odbc/columninfo.c b/src/interfaces/odbc/columninfo.c
index 1c635945074..d9a22a163a1 100644
--- a/src/interfaces/odbc/columninfo.c
+++ b/src/interfaces/odbc/columninfo.c
@@ -13,6 +13,7 @@
*/
#include "columninfo.h"
+
#include "connection.h"
#include "socket.h"
#include <stdlib.h>
diff --git a/src/interfaces/odbc/connection.c b/src/interfaces/odbc/connection.c
index 54e448892bb..3e6c89863ce 100644
--- a/src/interfaces/odbc/connection.c
+++ b/src/interfaces/odbc/connection.c
@@ -14,12 +14,9 @@
*/
/* Multibyte support Eiji Tokuya 2001-03-15 */
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include "connection.h"
#include "environ.h"
-#include "connection.h"
#include "socket.h"
#include "statement.h"
#include "qresult.h"
diff --git a/src/interfaces/odbc/connection.h b/src/interfaces/odbc/connection.h
index 11379e4f2ff..4da6a7b7a85 100644
--- a/src/interfaces/odbc/connection.h
+++ b/src/interfaces/odbc/connection.h
@@ -9,15 +9,11 @@
#ifndef __CONNECTION_H__
#define __CONNECTION_H__
+#include "psqlodbc.h"
+
#include <stdlib.h>
#include <string.h>
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
-#include "psqlodbc.h"
-
#ifndef WIN32
#include "iodbc.h"
#include "isql.h"
diff --git a/src/interfaces/odbc/convert.c b/src/interfaces/odbc/convert.c
index 12d5ddf1b8a..59dffbdcf9e 100644
--- a/src/interfaces/odbc/convert.c
+++ b/src/interfaces/odbc/convert.c
@@ -17,16 +17,12 @@
*/
/* Multibyte support Eiji Tokuya 2001-03-15 */
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include "convert.h"
#include <stdio.h>
#include <string.h>
#include <ctype.h>
-#include "psqlodbc.h"
-
#ifdef MULTIBYTE
#include "multibyte.h"
#endif
@@ -44,7 +40,6 @@
#include <time.h>
#include <math.h>
#include <stdlib.h>
-#include "convert.h"
#include "statement.h"
#include "qresult.h"
#include "bind.h"
diff --git a/src/interfaces/odbc/convert.h b/src/interfaces/odbc/convert.h
index fed2239e3b1..4a142db3d5c 100644
--- a/src/interfaces/odbc/convert.h
+++ b/src/interfaces/odbc/convert.h
@@ -11,6 +11,8 @@
#include "psqlodbc.h"
+#include "isql.h"
+
/* copy_and_convert results */
#define COPY_OK 0
#define COPY_UNSUPPORTED_TYPE 1
diff --git a/src/interfaces/odbc/dlg_specific.c b/src/interfaces/odbc/dlg_specific.c
index c465f3fc280..d28fcf966c4 100644
--- a/src/interfaces/odbc/dlg_specific.c
+++ b/src/interfaces/odbc/dlg_specific.c
@@ -17,9 +17,7 @@
*/
/* Multibyte support Eiji Tokuya 2001-03-15 */
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include "psqlodbc.h"
#ifndef WIN32
#include <string.h>
diff --git a/src/interfaces/odbc/dlg_specific.h b/src/interfaces/odbc/dlg_specific.h
index 884fe2e85ce..67f99449754 100644
--- a/src/interfaces/odbc/dlg_specific.h
+++ b/src/interfaces/odbc/dlg_specific.h
@@ -9,10 +9,6 @@
#ifndef __DLG_SPECIFIC_H__
#define __DLG_SPECIFIC_H__
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
#include "psqlodbc.h"
#include "connection.h"
diff --git a/src/interfaces/odbc/drvconn.c b/src/interfaces/odbc/drvconn.c
index 6a8c563fafb..e224cbda5e7 100644
--- a/src/interfaces/odbc/drvconn.c
+++ b/src/interfaces/odbc/drvconn.c
@@ -12,14 +12,11 @@
*-------
*/
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include "psqlodbc.h"
#include <stdio.h>
#include <stdlib.h>
-#include "psqlodbc.h"
#include "connection.h"
#ifndef WIN32
diff --git a/src/interfaces/odbc/environ.c b/src/interfaces/odbc/environ.c
index 2ea5f28ef45..d21c0540cac 100644
--- a/src/interfaces/odbc/environ.c
+++ b/src/interfaces/odbc/environ.c
@@ -14,6 +14,7 @@
*/
#include "environ.h"
+
#include "connection.h"
#include "dlg_specific.h"
#include "statement.h"
diff --git a/src/interfaces/odbc/environ.h b/src/interfaces/odbc/environ.h
index cc7950ae5ee..6d50fa6b48f 100644
--- a/src/interfaces/odbc/environ.h
+++ b/src/interfaces/odbc/environ.h
@@ -9,10 +9,6 @@
#ifndef __ENVIRON_H__
#define __ENVIRON_H__
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
#include "psqlodbc.h"
#ifndef WIN32
diff --git a/src/interfaces/odbc/execute.c b/src/interfaces/odbc/execute.c
index 38eabfea6eb..374d700193d 100644
--- a/src/interfaces/odbc/execute.c
+++ b/src/interfaces/odbc/execute.c
@@ -13,10 +13,6 @@
*-------
*/
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
#include "psqlodbc.h"
#include <stdio.h>
#include <string.h>
diff --git a/src/interfaces/odbc/gpps.c b/src/interfaces/odbc/gpps.c
index 248f8e0fcd3..4b13fbe62e5 100644
--- a/src/interfaces/odbc/gpps.c
+++ b/src/interfaces/odbc/gpps.c
@@ -21,9 +21,7 @@
#ifndef WIN32
-#if HAVE_CONFIG_H
-#include "config.h" /* produced by configure */
-#endif
+#include "gpps.h"
#include <stdio.h>
#include <unistd.h>
@@ -36,7 +34,6 @@
#include <sys/types.h>
#include <string.h>
#include "misc.h"
-#include "gpps.h"
#include "dlg_specific.h"
#ifndef TRUE
@@ -286,7 +283,7 @@ WritePrivateProfileString(char *theSection, /* section name */
}
-#if 0
+#if NOT_USED
/*
* Ok. What the hell's the default behaviour for a null input buffer, and null
* section name. For now if either are null I ignore the request, until
@@ -449,7 +446,7 @@ if (!keyFound)
return aReturnLength > 0 ? aReturnLength - 1 : 0;
}
-#endif
+#endif /* NOT_USED */
-#endif
+#endif /* not WIN32 */
diff --git a/src/interfaces/odbc/gpps.h b/src/interfaces/odbc/gpps.h
index 5bbe10374b2..9dc9d64210a 100644
--- a/src/interfaces/odbc/gpps.h
+++ b/src/interfaces/odbc/gpps.h
@@ -4,9 +4,7 @@
#ifndef GPPS_H
#define GPPS_H
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include "psqlodbc.h"
#ifndef WIN32
#include <sys/types.h>
diff --git a/src/interfaces/odbc/info.c b/src/interfaces/odbc/info.c
index 79854d6cd2e..1bc96ac888c 100644
--- a/src/interfaces/odbc/info.c
+++ b/src/interfaces/odbc/info.c
@@ -16,13 +16,10 @@
*--------
*/
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include "psqlodbc.h"
#include <string.h>
#include <stdio.h>
-#include "psqlodbc.h"
#ifndef WIN32
#include "iodbc.h"
diff --git a/src/interfaces/odbc/misc.c b/src/interfaces/odbc/misc.c
index ae75320bb53..1bfb877cbf7 100644
--- a/src/interfaces/odbc/misc.c
+++ b/src/interfaces/odbc/misc.c
@@ -12,12 +12,12 @@
*-------
*/
+#include "psqlodbc.h"
+
#include <stdio.h>
#include <stdarg.h>
#include <string.h>
-#include "psqlodbc.h"
-
#ifndef WIN32
#if HAVE_PWD_H
#include <pwd.h>
@@ -120,10 +120,6 @@ qlog(char *fmt,...)
/* Undefine these because windows.h will redefine and cause a warning */
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
#ifdef WIN32
#undef va_start
#undef va_end
diff --git a/src/interfaces/odbc/misc.h b/src/interfaces/odbc/misc.h
index 5172e491f5d..dc2ef0d5bea 100644
--- a/src/interfaces/odbc/misc.h
+++ b/src/interfaces/odbc/misc.h
@@ -9,9 +9,7 @@
#ifndef __MISC_H__
#define __MISC_H__
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include "psqlodbc.h"
#ifndef WIN32
#include "gpps.h"
diff --git a/src/interfaces/odbc/multibyte.c b/src/interfaces/odbc/multibyte.c
index 4d25c0bb1ad..a9c9c2f83bb 100644
--- a/src/interfaces/odbc/multibyte.c
+++ b/src/interfaces/odbc/multibyte.c
@@ -7,8 +7,8 @@
*--------
*/
-#include <string.h>
#include "multibyte.h"
+#include <string.h>
int multibyte_client_encoding; /* Multibyte Client Encoding. */
int multibyte_status; /* Multibyte Odds and ends character. */
diff --git a/src/interfaces/odbc/multibyte.h b/src/interfaces/odbc/multibyte.h
index c7d8b20d951..43870458e0d 100644
--- a/src/interfaces/odbc/multibyte.h
+++ b/src/interfaces/odbc/multibyte.h
@@ -3,6 +3,7 @@
* Multibyte library header ( psqlODBC Only )
*
*/
+#include "psqlodbc.h"
/* PostgreSQL client encoding */
#define SQL_ASCII 0 /* SQL/ASCII */
diff --git a/src/interfaces/odbc/odbcapi.c b/src/interfaces/odbc/odbcapi.c
index a69c3d1a944..60205c011b6 100644
--- a/src/interfaces/odbc/odbcapi.c
+++ b/src/interfaces/odbc/odbcapi.c
@@ -26,10 +26,6 @@
*-------
*/
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
#include "psqlodbc.h"
#ifdef WIN32
#undef ODBCVER
diff --git a/src/interfaces/odbc/odbcapi30.c b/src/interfaces/odbc/odbcapi30.c
index 9902be746df..cee57934df2 100644
--- a/src/interfaces/odbc/odbcapi30.c
+++ b/src/interfaces/odbc/odbcapi30.c
@@ -18,10 +18,6 @@
*-------
*/
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
#include "psqlodbc.h"
#undef ODBCVER
#define ODBCVER 0x0300
diff --git a/src/interfaces/odbc/options.c b/src/interfaces/odbc/options.c
index 82b651cdc58..77421b63ebd 100644
--- a/src/interfaces/odbc/options.c
+++ b/src/interfaces/odbc/options.c
@@ -13,10 +13,6 @@
*--------
*/
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
#include "psqlodbc.h"
#include <string.h>
diff --git a/src/interfaces/odbc/parse.c b/src/interfaces/odbc/parse.c
index 8916db2072d..eb0589e4c4b 100644
--- a/src/interfaces/odbc/parse.c
+++ b/src/interfaces/odbc/parse.c
@@ -22,9 +22,7 @@
*/
/* Multibyte support Eiji Tokuya 2001-03-15 */
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include "psqlodbc.h"
#include <stdio.h>
#include <string.h>
diff --git a/src/interfaces/odbc/pgapifunc.h b/src/interfaces/odbc/pgapifunc.h
index fda018f61f9..a4aca5f323d 100644
--- a/src/interfaces/odbc/pgapifunc.h
+++ b/src/interfaces/odbc/pgapifunc.h
@@ -5,9 +5,6 @@
*/
#ifndef _PG_API_FUNC_H__
#define _PG_API_FUNC_H__
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
#include "psqlodbc.h"
#include <stdio.h>
diff --git a/src/interfaces/odbc/pgtypes.c b/src/interfaces/odbc/pgtypes.c
index ff640776f8b..fdc38d62a19 100644
--- a/src/interfaces/odbc/pgtypes.c
+++ b/src/interfaces/odbc/pgtypes.c
@@ -16,13 +16,9 @@
*--------
*/
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include "pgtypes.h"
-#include "psqlodbc.h"
#include "dlg_specific.h"
-#include "pgtypes.h"
#include "statement.h"
#include "connection.h"
#include "qresult.h"
diff --git a/src/interfaces/odbc/psqlodbc.c b/src/interfaces/odbc/psqlodbc.c
index 4eabeae5ff3..9851af2ee66 100644
--- a/src/interfaces/odbc/psqlodbc.c
+++ b/src/interfaces/odbc/psqlodbc.c
@@ -13,10 +13,6 @@
*--------
*/
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
#include "psqlodbc.h"
#include "dlg_specific.h"
diff --git a/src/interfaces/odbc/psqlodbc.h b/src/interfaces/odbc/psqlodbc.h
index df077106512..542fe7ff596 100644
--- a/src/interfaces/odbc/psqlodbc.h
+++ b/src/interfaces/odbc/psqlodbc.h
@@ -5,7 +5,7 @@
*
* Comments: See "notice.txt" for copyright and license information.
*
- * $Id: psqlodbc.h,v 1.45 2001/08/18 04:30:47 inoue Exp $
+ * $Id: psqlodbc.h,v 1.46 2001/08/24 14:07:50 petere Exp $
*
*/
@@ -13,7 +13,7 @@
#define __PSQLODBC_H__
#ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "pg_config.h"
#endif
#include <stdio.h> /* for FILE* pointers: see GLOBAL_VALUES */
diff --git a/src/interfaces/odbc/qresult.h b/src/interfaces/odbc/qresult.h
index 7da2a0201ec..29e171bad80 100644
--- a/src/interfaces/odbc/qresult.h
+++ b/src/interfaces/odbc/qresult.h
@@ -9,11 +9,12 @@
#ifndef __QRESULT_H__
#define __QRESULT_H__
+#include "psqlodbc.h"
+
#include "connection.h"
#include "socket.h"
#include "columninfo.h"
#include "tuplelist.h"
-#include "psqlodbc.h"
#include "tuple.h"
enum QueryResultCode_
diff --git a/src/interfaces/odbc/results.c b/src/interfaces/odbc/results.c
index 098c5581d62..bb1f2975df6 100644
--- a/src/interfaces/odbc/results.c
+++ b/src/interfaces/odbc/results.c
@@ -15,12 +15,9 @@
*-------
*/
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include "psqlodbc.h"
#include <string.h>
-#include "psqlodbc.h"
#include "dlg_specific.h"
#include "environ.h"
#include "connection.h"
diff --git a/src/interfaces/odbc/socket.c b/src/interfaces/odbc/socket.c
index 243df4a5014..ed3fd2913c6 100644
--- a/src/interfaces/odbc/socket.c
+++ b/src/interfaces/odbc/socket.c
@@ -12,10 +12,6 @@
*-------
*/
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
#include "socket.h"
#ifndef WIN32
diff --git a/src/interfaces/odbc/socket.h b/src/interfaces/odbc/socket.h
index b4a55e57db6..b24be9504d4 100644
--- a/src/interfaces/odbc/socket.h
+++ b/src/interfaces/odbc/socket.h
@@ -9,9 +9,7 @@
#ifndef __SOCKET_H__
#define __SOCKET_H__
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include "psqlodbc.h"
#ifndef WIN32
#include <sys/types.h>
diff --git a/src/interfaces/odbc/statement.c b/src/interfaces/odbc/statement.c
index 3ab683d4a04..891f47df831 100644
--- a/src/interfaces/odbc/statement.c
+++ b/src/interfaces/odbc/statement.c
@@ -12,10 +12,6 @@
*-------
*/
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
#include "statement.h"
#include "bind.h"
#include "connection.h"
diff --git a/src/interfaces/odbc/statement.h b/src/interfaces/odbc/statement.h
index 6250a934a5a..571d13edaca 100644
--- a/src/interfaces/odbc/statement.h
+++ b/src/interfaces/odbc/statement.h
@@ -9,10 +9,6 @@
#ifndef __STATEMENT_H__
#define __STATEMENT_H__
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
#include "psqlodbc.h"
#include "bind.h"
diff --git a/src/interfaces/odbc/tuplelist.c b/src/interfaces/odbc/tuplelist.c
index 06fd2d44ff8..284ee8ed440 100644
--- a/src/interfaces/odbc/tuplelist.c
+++ b/src/interfaces/odbc/tuplelist.c
@@ -13,8 +13,8 @@
*--------
*/
-#include <stdlib.h>
#include "tuplelist.h"
+#include <stdlib.h>
#include "tuple.h"
diff --git a/src/interfaces/python/GNUmakefile b/src/interfaces/python/GNUmakefile
index e405cf3a9f4..2be8fe1d186 100644
--- a/src/interfaces/python/GNUmakefile
+++ b/src/interfaces/python/GNUmakefile
@@ -1,4 +1,4 @@
-# $Header: /cvsroot/pgsql/src/interfaces/python/Attic/GNUmakefile,v 1.10 2001/07/10 16:33:02 petere Exp $
+# $Header: /cvsroot/pgsql/src/interfaces/python/Attic/GNUmakefile,v 1.11 2001/08/24 14:07:50 petere Exp $
subdir = src/interfaces/python
top_builddir = ../../..
@@ -17,7 +17,6 @@ endif
include $(top_srcdir)/src/Makefile.shlib
-# (Python also has a config.h file. Be sure to use ours.)
override CPPFLAGS := -I$(libpq_srcdir) $(CPPFLAGS) $(python_includespec)
all: all-lib
diff --git a/src/tools/pginclude/pgrminclude b/src/tools/pginclude/pgrminclude
index 60839c15dca..6504aad82a0 100755
--- a/src/tools/pginclude/pgrminclude
+++ b/src/tools/pginclude/pgrminclude
@@ -4,7 +4,7 @@
trap "rm -f /tmp/$$.c /tmp/$$.o /tmp/$$ /tmp/$$a /tmp/$$b" 0 1 2 3 15
find . \( -name CVS -a -prune \) -o -type f -print |
grep -v '\./postgres.h' |
-grep -v '\./config.h' |
+grep -v '\./pg_config.h' |
grep -v '\./c.h' |
while read FILE
do
diff --git a/src/backend/catalog/genbki.sh b/src/backend/catalog/genbki.sh
index 260d680f7b3..3d51423af42 100644
--- a/src/backend/catalog/genbki.sh
+++ b/src/backend/catalog/genbki.sh
@@ -10,7 +10,7 @@
#
#
# IDENTIFICATION
-# $Header: /cvsroot/pgsql/src/backend/catalog/Attic/genbki.sh,v 1.21 2001/08/10 18:57:33 tgl Exp $
+# $Header: /cvsroot/pgsql/src/backend/catalog/Attic/genbki.sh,v 1.22 2001/08/24 14:07:48 petere Exp $
#
# NOTES
# non-essential whitespace is removed from the generated file.
@@ -66,7 +66,7 @@ do
echo " $CMDNAME [ -D define [...] ] [ -I dir ] --set-version=VERSION -o prefix files..."
echo
echo "Options:"
- echo " -I path to postgres_ext.h and config.h files"
+ echo " -I path to postgres_ext.h and pg_config.h files"
echo " -o prefix of output files"
echo " --set-version PostgreSQL version number for initdb cross-check"
echo
@@ -126,12 +126,12 @@ for dir in $INCLUDE_DIRS; do
fi
done
# Get INDEX_MAX_KEYS and DEFAULT_ATTSTATTARGET from config.h
# (who needs consistency?)
for dir in $INCLUDE_DIRS; do
- if [ -f "$dir/config.h" ]; then
- INDEXMAXKEYS=`grep '#define[ ]*INDEX_MAX_KEYS' $dir/config.h | $AWK '{ print $3 }'`
- DEFAULTATTSTATTARGET=`grep '#define[ ]*DEFAULT_ATTSTATTARGET' $dir/config.h | $AWK '{ print $3 }'`
+ if [ -f "$dir/pg_config.h" ]; then
+ INDEXMAXKEYS=`grep '#define[ ]*INDEX_MAX_KEYS' $dir/pg_config.h | $AWK '{ print $3 }'`
+ DEFAULTATTSTATTARGET=`grep '#define[ ]*DEFAULT_ATTSTATTARGET' $dir/pg_config.h | $AWK '{ print $3 }'`
break
fi
done
@@ -146,7 +146,7 @@ done
export BKIOBJECTID
# NOTE: we assume here that FUNC_MAX_ARGS has the same value as INDEX_MAX_KEYS,
# and don't read it separately from config.h. This is OK because both of them
# must be equal to the length of oidvector.
INDEXMAXKEYS2=`expr $INDEXMAXKEYS '*' 2` || exit
@@ -126,12 +126,12 @@ for dir in $INCLUDE_DIRS; do
fi
done
-# Get INDEX_MAX_KEYS and DEFAULT_ATTSTATTARGET from config.h
+# Get INDEX_MAX_KEYS and DEFAULT_ATTSTATTARGET from pg_config.h
# (who needs consistency?)
for dir in $INCLUDE_DIRS; do
@@ -146,7 +146,7 @@ done
export BKIOBJECTID
# NOTE: we assume here that FUNC_MAX_ARGS has the same value as INDEX_MAX_KEYS,
-# and don't read it separately from config.h. This is OK because both of them
+# and don't read it separately from pg_config.h. This is OK because both of them
# must be equal to the length of oidvector.
INDEXMAXKEYS2=`expr $INDEXMAXKEYS '*' 2` || exit